@@ -99,14 +99,14 @@ class AbstractColumn(object):
             rows = tbl.read()
         else:
             if has_pytables3:
-                rows = tbl.read_coordinates(rowNumbers)
+                rows = tbl.read_coordinates(rowNumbers, field=self.name)
             else:
-                rows = tbl.readCoordinates(rowNumbers)
-        self.fromrows(rows)
+                rows = tbl.readCoordinates(rowNumbers, field=self.name)
+        self.fromrows(rows, field_only=True)
 
     def read(self, tbl, start, stop):
-        rows = tbl.read(start, stop)
-        self.fromrows(rows)
+        rows = tbl.read(start, stop, field=self.name)
+        self.fromrows(rows, field_only=True)
 
     def getsize(self):
         """
@@ -143,12 +143,17 @@ class AbstractColumn(object):
         names = [self.name + sn for sn in self._subnames]
         return list(zip(names, self._types))
 
-    def fromrows(self, rows):
+    def fromrows(self, rows, field_only=False):
         """
         Any method which does not use the "values" field
         will need to override this method.
         """
-        self.values = rows[self.name]
+
+        if not field_only:
+            rows = rows[self.name]
+
+        self.values = rows
+
         # WORKAROUND:
         # http://www.zeroc.com/forums/bug-reports/4165-icepy-can-not-handle-buffers-longs-i64.html#post20468
         # see ticket:1951 and #2160
@@ -199,6 +204,15 @@ class PlateColumnI(AbstractColumn, omero.grid.PlateColumn):
     def descriptor(self, pos):
         return tables.Int64Col(pos=pos)
 
+class DatasetColumnI(AbstractColumn, omero.grid.DatasetColumn):
+
+    def __init__(self, name="Unknown", *args):
+        omero.grid.DatasetColumn.__init__(self, name, *args)
+        AbstractColumn.__init__(self)
+
+    def descriptor(self, pos):
+        return tables.Int64Col(pos=pos)
+
 
 class RoiColumnI(AbstractColumn, omero.grid.RoiColumn):
 
@@ -312,8 +326,8 @@ class StringColumnI(AbstractColumn, omero.grid.StringColumn):
                 % self.name)
         return tables.StringCol(pos=pos, itemsize=self.size)
 
-    def fromrows(self, rows):
-        AbstractColumn.fromrows(self, rows)
+    def fromrows(self, rows, field_only=False):
+        AbstractColumn.fromrows(self, rows, field_only=field_only)
         for i, val in enumerate(self.values):
             if isbytes(val):
                 self.values[i] = bytes_to_native_str(val)
@@ -508,7 +522,8 @@ class MaskColumnI(AbstractColumn, omero.grid.MaskColumn):
 
     def read(self, tbl, start, stop):
         self.__sanitycheck()
-        AbstractColumn.read(self, tbl, start, stop)  # calls fromrows
+        # calls fromrows
+        AbstractColumn.read(self, tbl, start, stop)
         masks = self._getmasks(tbl)
         rowNumbers = list(range(start, stop))
         self.getbytes(masks, rowNumbers)
@@ -518,8 +533,11 @@ class MaskColumnI(AbstractColumn, omero.grid.MaskColumn):
         for idx in rowNumbers:
             self.bytes.append(masks[idx].tolist())
 
-    def fromrows(self, all_rows):
-        rows = all_rows[self.name]
+    def fromrows(self, rows, field_only=False):
+
+        if not field_only:
+            rows = rows[self.name]
+
         # WORKAROUND:
         # http://www.zeroc.com/forums/bug-reports/4165-icepy-can-not-handle-buffers-longs-i64.html#post20468
         self.imageId = rows["i"].tolist()
@@ -587,6 +605,7 @@ ObjectFactories = {
     RoiColumnI: ObjectFactory(RoiColumnI, lambda: RoiColumnI()),
     WellColumnI: ObjectFactory(WellColumnI, lambda: WellColumnI()),
     PlateColumnI: ObjectFactory(PlateColumnI, lambda: PlateColumnI()),
+    DatasetColumnI: ObjectFactory(DatasetColumnI, lambda: DatasetColumnI()),
     BoolColumnI: ObjectFactory(BoolColumnI, lambda: BoolColumnI()),
     DoubleColumnI: ObjectFactory(DoubleColumnI, lambda: DoubleColumnI()),
     LongColumnI: ObjectFactory(LongColumnI, lambda: LongColumnI()),
